diff --git a/.github/CODEOWNERS b/.github/CODEOWNERS
index f47bfaf1d4ee3..b05768a1dd63c 100644
--- a/.github/CODEOWNERS
+++ b/.github/CODEOWNERS
@@ -60,7 +60,7 @@ platforms/core-execution/build-cache-packaging/ @gradle/bt-execution
platforms/core-execution/hashing/ @gradle/bt-execution @gradle/bt-ge-build-cache
platforms/core-execution/snapshots/ @gradle/bt-execution @gradle/bt-ge-build-cache
-# Gradle Enterprise integration
+# Develocity integration
platforms/enterprise/ @gradle/bt-build-scan @gradle/ge-build-insights
platforms/enterprise/enterprise/ @gradle/bt-build-scan @gradle/ge-testing @gradle/ge-build-insights @ldaley
platforms/enterprise/enterprise-logging/ @gradle/bt-build-scan @gradle/ge-build-insights @gradle/ge-testing
diff --git a/build-logic/settings.gradle.kts b/build-logic/settings.gradle.kts
index 3b2d0fcd56b23..c3c1a8c215bd7 100644
--- a/build-logic/settings.gradle.kts
+++ b/build-logic/settings.gradle.kts
@@ -28,7 +28,7 @@ plugins {
dependencyResolutionManagement {
repositories {
maven {
- name = "Gradle Enterprise release candidates"
+ name = "Develocity release candidates"
url = uri("https://repo.gradle.org/gradle/enterprise-libs-release-candidates")
content {
val rcAndMilestonesPattern = "\\d{1,2}?\\.\\d{1,2}?(\\.\\d{1,2}?)?-((rc-\\d{1,2}?)|(milestone-\\d{1,2}?))"
diff --git a/platforms/core-configuration/configuration-cache/src/main/kotlin/org/gradle/configurationcache/ConfigurationCacheState.kt b/platforms/core-configuration/configuration-cache/src/main/kotlin/org/gradle/configurationcache/ConfigurationCacheState.kt
index b7a2aab7e009f..803a4190e4835 100644
--- a/platforms/core-configuration/configuration-cache/src/main/kotlin/org/gradle/configurationcache/ConfigurationCacheState.kt
+++ b/platforms/core-configuration/configuration-cache/src/main/kotlin/org/gradle/configurationcache/ConfigurationCacheState.kt
@@ -569,7 +569,7 @@ class ConfigurationCacheState(
readCachedEnvironmentState(gradle)
readPreviewFlags(gradle)
readFileSystemDefaultExcludes(gradle)
- // It is important that the Gradle Enterprise plugin be read before
+ // It is important that the Develocity plugin be read before
// build cache configuration, as it may contribute build cache configuration.
readGradleEnterprisePluginManager(gradle)
readBuildCacheConfiguration(gradle)
diff --git a/platforms/core-configuration/kotlin-dsl/doc/c4/C4_1_Context.puml b/platforms/core-configuration/kotlin-dsl/doc/c4/C4_1_Context.puml
index da4e7fde95c71..72cb33e438e7c 100644
--- a/platforms/core-configuration/kotlin-dsl/doc/c4/C4_1_Context.puml
+++ b/platforms/core-configuration/kotlin-dsl/doc/c4/C4_1_Context.puml
@@ -15,7 +15,7 @@ System_Ext(ide, "IntelliJ IDE", "IDEA or Android Studio with the Kotlin plugin e
System_Ext(kotlinTools, "Kotlin Toolchain", "kotlinc, Gradle plugin etc...")
-System_Ext(buildCache, "Gradle Build Cache", "Local, Gradle Enterprise Build Cache Node, etc...")
+System_Ext(buildCache, "Gradle Build Cache", "Local, Develocity Build Cache Node, etc...")
Rel(dev, gradle, "Uses", "Command Line")
Rel(gradleKotlinDsl, kotlinTools, "Uses")
diff --git a/platforms/core-configuration/kotlin-dsl/doc/c4/C4_2_Container.puml b/platforms/core-configuration/kotlin-dsl/doc/c4/C4_2_Container.puml
index 42314120adc07..ef9ede289ef36 100644
--- a/platforms/core-configuration/kotlin-dsl/doc/c4/C4_2_Container.puml
+++ b/platforms/core-configuration/kotlin-dsl/doc/c4/C4_2_Container.puml
@@ -44,7 +44,7 @@ System_Boundary(kotlinTools, "Kotlin Toolchain") {
Rel_Neighbor(kgp, kotlinc, "Uses", "Daemon")
}
-System_Ext(buildCache, "Gradle Build Cache", "Local, Gradle Enterprise Build Cache Node, etc...")
+System_Ext(buildCache, "Gradle Build Cache", "Local, Develocity Build Cache Node, etc...")
Rel(dev, gradle, "Uses", "Command Line")
Rel(dev, editor, "Uses", "GUI")
diff --git a/platforms/core-configuration/kotlin-dsl/doc/c4/C4_3_Component.puml b/platforms/core-configuration/kotlin-dsl/doc/c4/C4_3_Component.puml
index 958ded5ae6f7b..c1c4a2ce2f18f 100644
--- a/platforms/core-configuration/kotlin-dsl/doc/c4/C4_3_Component.puml
+++ b/platforms/core-configuration/kotlin-dsl/doc/c4/C4_3_Component.puml
@@ -103,7 +103,7 @@ Boundary(kotlinTools, "Kotlin Toolchain") {
Rel_Neighbor(kgp, kotlinc, "Uses", "Daemon")
}
-System_Ext(buildCache, "Gradle Build Cache", "Local, Gradle Enterprise Build Cache Node, etc...")
+System_Ext(buildCache, "Gradle Build Cache", "Local, Develocity Build Cache Node, etc...")
Rel(dev, gradle, "Uses", "Command Line")
Rel(dev, editor, "Uses", "GUI")
diff --git a/platforms/core-configuration/kotlin-dsl/doc/c4/images/C4_1_Context.svg b/platforms/core-configuration/kotlin-dsl/doc/c4/images/C4_1_Context.svg
index 7142e95365171..4c2780a893449 100644
--- a/platforms/core-configuration/kotlin-dsl/doc/c4/images/C4_1_Context.svg
+++ b/platforms/core-configuration/kotlin-dsl/doc/c4/images/C4_1_Context.svg
@@ -1,4 +1,4 @@
-
\ No newline at end of file
+-->
diff --git a/platforms/core-configuration/kotlin-dsl/doc/c4/images/C4_2_Container.svg b/platforms/core-configuration/kotlin-dsl/doc/c4/images/C4_2_Container.svg
index fbd06bcfff560..e4052492d6cf0 100644
--- a/platforms/core-configuration/kotlin-dsl/doc/c4/images/C4_2_Container.svg
+++ b/platforms/core-configuration/kotlin-dsl/doc/c4/images/C4_2_Container.svg
@@ -1,4 +1,4 @@
-
\ No newline at end of file
+-->
diff --git a/platforms/core-configuration/kotlin-dsl/doc/c4/images/C4_3_Component.svg b/platforms/core-configuration/kotlin-dsl/doc/c4/images/C4_3_Component.svg
index e30eaa52a7bd2..e31b88189eea3 100644
--- a/platforms/core-configuration/kotlin-dsl/doc/c4/images/C4_3_Component.svg
+++ b/platforms/core-configuration/kotlin-dsl/doc/c4/images/C4_3_Component.svg
@@ -1,4 +1,4 @@
-
\ No newline at end of file
+-->
diff --git a/platforms/enterprise/enterprise-logging/build.gradle.kts b/platforms/enterprise/enterprise-logging/build.gradle.kts
index 3bc57d4b791c6..9937883eeeaad 100644
--- a/platforms/enterprise/enterprise-logging/build.gradle.kts
+++ b/platforms/enterprise/enterprise-logging/build.gradle.kts
@@ -2,7 +2,7 @@ plugins {
id("gradlebuild.distribution.api-java")
}
-description = "Logging API consumed by the Gradle Enterprise plugin"
+description = "Logging API consumed by the Develocity plugin"
gradlebuildJava.usedInWorkers()
diff --git a/platforms/enterprise/enterprise-operations/build.gradle.kts b/platforms/enterprise/enterprise-operations/build.gradle.kts
index dae7bbf36c91f..945c028294b8a 100644
--- a/platforms/enterprise/enterprise-operations/build.gradle.kts
+++ b/platforms/enterprise/enterprise-operations/build.gradle.kts
@@ -3,7 +3,7 @@ plugins {
id("gradlebuild.publish-public-libraries")
}
-description = "Build operations consumed by the Gradle Enterprise plugin"
+description = "Build operations consumed by the Develocity plugin"
dependencies {
api(project(":build-operations"))
diff --git a/platforms/enterprise/enterprise-operations/src/main/java/org/gradle/api/internal/tasks/SnapshotTaskInputsBuildOperationType.java b/platforms/enterprise/enterprise-operations/src/main/java/org/gradle/api/internal/tasks/SnapshotTaskInputsBuildOperationType.java
index 22b620cc37f38..79aa154dafd80 100644
--- a/platforms/enterprise/enterprise-operations/src/main/java/org/gradle/api/internal/tasks/SnapshotTaskInputsBuildOperationType.java
+++ b/platforms/enterprise/enterprise-operations/src/main/java/org/gradle/api/internal/tasks/SnapshotTaskInputsBuildOperationType.java
@@ -162,7 +162,7 @@ interface VisitState extends FilePropertyVisitor.VisitState {
/**
* The “primary” attribute of the current property.
*
- * Used by Gradle Enterprise plugin < 3.8, retained for backwards compatibility.
+ * Used by Develocity plugin < 3.8, retained for backwards compatibility.
*
* Returns the name value of one of:
*
@@ -194,7 +194,7 @@ interface VisitState extends FilePropertyVisitor.VisitState {
* No null values.
* Never empty.
*
- * This is kept for backward compatibility with the Gradle Enterprise Gradle plugin.
+ * This is kept for backward compatibility with the Develocity Gradle plugin.
*
* @deprecated Always null, since we don't capture inputs when anything is loaded by an unknown classloader.
*/
diff --git a/platforms/enterprise/enterprise-workers/build.gradle.kts b/platforms/enterprise/enterprise-workers/build.gradle.kts
index 463526a99b979..3ead4f44b5a09 100644
--- a/platforms/enterprise/enterprise-workers/build.gradle.kts
+++ b/platforms/enterprise/enterprise-workers/build.gradle.kts
@@ -3,7 +3,7 @@ plugins {
id("gradlebuild.publish-public-libraries")
}
-description = "Gradle Enterprise plugin dependencies that also need to be exposed to workers"
+description = "Develocity plugin dependencies that also need to be exposed to workers"
gradlebuildJava.usedInWorkers()
diff --git a/platforms/enterprise/enterprise/build.gradle.kts b/platforms/enterprise/enterprise/build.gradle.kts
index ba5f5ebea85fe..b4384de329a52 100644
--- a/platforms/enterprise/enterprise/build.gradle.kts
+++ b/platforms/enterprise/enterprise/build.gradle.kts
@@ -2,7 +2,7 @@ plugins {
id("gradlebuild.distribution.api-java")
}
-description = "Services and utilities needed by Gradle Enterprise plugin"
+description = "Services and utilities needed by Develocity plugin"
dependencies {
api(project(":base-services"))
diff --git a/platforms/enterprise/enterprise/src/integTest/groovy/org/gradle/internal/enterprise/GradleEnterprisePluginCheckInIntegrationTest.groovy b/platforms/enterprise/enterprise/src/integTest/groovy/org/gradle/internal/enterprise/GradleEnterprisePluginCheckInIntegrationTest.groovy
index 7d7739ea45be4..c067a43535729 100644
--- a/platforms/enterprise/enterprise/src/integTest/groovy/org/gradle/internal/enterprise/GradleEnterprisePluginCheckInIntegrationTest.groovy
+++ b/platforms/enterprise/enterprise/src/integTest/groovy/org/gradle/internal/enterprise/GradleEnterprisePluginCheckInIntegrationTest.groovy
@@ -97,7 +97,7 @@ class GradleEnterprisePluginCheckInIntegrationTest extends AbstractIntegrationSp
}
@Requires(IntegTestPreconditions.NotConfigCached)
- def "shows warning message when unsupported Gradle Enterprise plugin version is used with configuration caching enabled"() {
+ def "shows warning message when unsupported Develocity plugin version is used with configuration caching enabled"() {
given:
plugin.runtimeVersion = pluginVersion
plugin.artifactVersion = pluginVersion
@@ -108,7 +108,7 @@ class GradleEnterprisePluginCheckInIntegrationTest extends AbstractIntegrationSp
when:
if (applied && VersionNumber.parse(pluginVersion) < MINIMUM_SUPPORTED_PLUGIN_VERSION_SINCE_GRADLE_9) {
- executer.expectDocumentedDeprecationWarning("Gradle Enterprise plugin $pluginVersion has been deprecated. Starting with Gradle 9.0, only Gradle Enterprise plugin 3.13.1 or newer is supported. Consult the upgrading guide for further information: https://docs.gradle.org/current/userguide/upgrading_version_8.html#unsupported_ge_plugin_3.13")
+ executer.expectDocumentedDeprecationWarning("Develocity plugin $pluginVersion has been deprecated. Starting with Gradle 9.0, only Develocity plugin 3.13.1 or newer is supported. Consult the upgrading guide for further information: https://docs.gradle.org/current/userguide/upgrading_version_8.html#unsupported_ge_plugin_3.13")
}
succeeds("t", "--configuration-cache")
@@ -125,7 +125,7 @@ class GradleEnterprisePluginCheckInIntegrationTest extends AbstractIntegrationSp
}
@Requires(value = IntegTestPreconditions.NotConfigCached, reason = "Isolated projects implies config cache")
- def "shows warning message when Gradle Enterprise plugin version is used with isolated projects enabled"() {
+ def "shows warning message when Develocity plugin version is used with isolated projects enabled"() {
given:
plugin.runtimeVersion = pluginVersion
plugin.artifactVersion = pluginVersion
diff --git a/platforms/enterprise/enterprise/src/integTest/groovy/org/gradle/internal/enterprise/core/BuildScanAutoApplyIntegrationTest.groovy b/platforms/enterprise/enterprise/src/integTest/groovy/org/gradle/internal/enterprise/core/BuildScanAutoApplyIntegrationTest.groovy
index 47341b94c4ce1..449cda8bb17a4 100644
--- a/platforms/enterprise/enterprise/src/integTest/groovy/org/gradle/internal/enterprise/core/BuildScanAutoApplyIntegrationTest.groovy
+++ b/platforms/enterprise/enterprise/src/integTest/groovy/org/gradle/internal/enterprise/core/BuildScanAutoApplyIntegrationTest.groovy
@@ -120,7 +120,7 @@ class BuildScanAutoApplyIntegrationTest extends AbstractIntegrationSpec {
and:
if (!GradleContextualExecuter.configCache && VersionNumber.parse(version) < PLUGIN_MINIMUM_NON_DEPRECATED_VERSION) {
- executer.expectDocumentedDeprecationWarning("Gradle Enterprise plugin $version has been deprecated. Starting with Gradle 9.0, only Gradle Enterprise plugin 3.13.1 or newer is supported. Consult the upgrading guide for further information: https://docs.gradle.org/current/userguide/upgrading_version_8.html#unsupported_ge_plugin_3.13")
+ executer.expectDocumentedDeprecationWarning("Develocity plugin $version has been deprecated. Starting with Gradle 9.0, only Develocity plugin 3.13.1 or newer is supported. Consult the upgrading guide for further information: https://docs.gradle.org/current/userguide/upgrading_version_8.html#unsupported_ge_plugin_3.13")
}
and:
@@ -154,7 +154,7 @@ class BuildScanAutoApplyIntegrationTest extends AbstractIntegrationSpec {
and:
if (!GradleContextualExecuter.configCache && VersionNumber.parse(version) < PLUGIN_MINIMUM_NON_DEPRECATED_VERSION) {
- executer.expectDocumentedDeprecationWarning("Gradle Enterprise plugin $version has been deprecated. Starting with Gradle 9.0, only Gradle Enterprise plugin 3.13.1 or newer is supported. Consult the upgrading guide for further information: https://docs.gradle.org/current/userguide/upgrading_version_8.html#unsupported_ge_plugin_3.13")
+ executer.expectDocumentedDeprecationWarning("Develocity plugin $version has been deprecated. Starting with Gradle 9.0, only Develocity plugin 3.13.1 or newer is supported. Consult the upgrading guide for further information: https://docs.gradle.org/current/userguide/upgrading_version_8.html#unsupported_ge_plugin_3.13")
}
and:
@@ -192,7 +192,7 @@ class BuildScanAutoApplyIntegrationTest extends AbstractIntegrationSpec {
and:
if (!GradleContextualExecuter.configCache && VersionNumber.parse(version) < PLUGIN_MINIMUM_NON_DEPRECATED_VERSION) {
- executer.expectDocumentedDeprecationWarning("Gradle Enterprise plugin $version has been deprecated. Starting with Gradle 9.0, only Gradle Enterprise plugin 3.13.1 or newer is supported. Consult the upgrading guide for further information: https://docs.gradle.org/current/userguide/upgrading_version_8.html#unsupported_ge_plugin_3.13")
+ executer.expectDocumentedDeprecationWarning("Develocity plugin $version has been deprecated. Starting with Gradle 9.0, only Develocity plugin 3.13.1 or newer is supported. Consult the upgrading guide for further information: https://docs.gradle.org/current/userguide/upgrading_version_8.html#unsupported_ge_plugin_3.13")
}
and:
diff --git a/platforms/enterprise/enterprise/src/integTest/groovy/org/gradle/internal/enterprise/legacy/LegacyGradleEnterpriseCheckInConfigCachingIntegTest.groovy b/platforms/enterprise/enterprise/src/integTest/groovy/org/gradle/internal/enterprise/legacy/LegacyGradleEnterpriseCheckInConfigCachingIntegTest.groovy
index 0ffeaeecf66c2..fb98ebd7e28e9 100644
--- a/platforms/enterprise/enterprise/src/integTest/groovy/org/gradle/internal/enterprise/legacy/LegacyGradleEnterpriseCheckInConfigCachingIntegTest.groovy
+++ b/platforms/enterprise/enterprise/src/integTest/groovy/org/gradle/internal/enterprise/legacy/LegacyGradleEnterpriseCheckInConfigCachingIntegTest.groovy
@@ -44,7 +44,7 @@ class LegacyGradleEnterpriseCheckInConfigCachingIntegTest extends AbstractIntegr
succeeds "t", "--configuration-cache"
then:
- scanPlugin.assertUnsupportedMessage(output, "Build scans have been disabled due to incompatibility between your Gradle Enterprise plugin version (3.3.4) and configuration caching. Please use Gradle Enterprise plugin version 3.4 or later for compatibility with configuration caching.")
+ scanPlugin.assertUnsupportedMessage(output, "Build scans have been disabled due to incompatibility between your Develocity plugin version (3.3.4) and configuration caching. Please use Develocity plugin version 3.4 or later for compatibility with configuration caching.")
}
}
diff --git a/platforms/enterprise/enterprise/src/main/java/org/gradle/internal/enterprise/impl/legacy/LegacyGradleEnterprisePluginCheckInService.java b/platforms/enterprise/enterprise/src/main/java/org/gradle/internal/enterprise/impl/legacy/LegacyGradleEnterprisePluginCheckInService.java
index 903f680d05416..77f2e42caa728 100644
--- a/platforms/enterprise/enterprise/src/main/java/org/gradle/internal/enterprise/impl/legacy/LegacyGradleEnterprisePluginCheckInService.java
+++ b/platforms/enterprise/enterprise/src/main/java/org/gradle/internal/enterprise/impl/legacy/LegacyGradleEnterprisePluginCheckInService.java
@@ -70,8 +70,8 @@ private String unsupportedReason(VersionNumber pluginVersion) {
if (Boolean.getBoolean(UNSUPPORTED_TOGGLE)) {
return UNSUPPORTED_TOGGLE_MESSAGE;
} else if (buildModelParameters.isConfigurationCache()) {
- return "Build scans have been disabled due to incompatibility between your Gradle Enterprise plugin version (" + pluginVersion.toString() + ") and configuration caching. " +
- "Please use Gradle Enterprise plugin version 3.4 or later for compatibility with configuration caching.";
+ return "Build scans have been disabled due to incompatibility between your Develocity plugin version (" + pluginVersion.toString() + ") and configuration caching. " +
+ "Please use Develocity plugin version 3.4 or later for compatibility with configuration caching.";
} else {
return null;
}
diff --git a/platforms/software/dependency-management/src/main/java/org/gradle/api/internal/artifacts/transform/TransformStepNode.java b/platforms/software/dependency-management/src/main/java/org/gradle/api/internal/artifacts/transform/TransformStepNode.java
index bdc0dfe2e058f..66c219eab9956 100644
--- a/platforms/software/dependency-management/src/main/java/org/gradle/api/internal/artifacts/transform/TransformStepNode.java
+++ b/platforms/software/dependency-management/src/main/java/org/gradle/api/internal/artifacts/transform/TransformStepNode.java
@@ -368,7 +368,7 @@ public TransformStepSubject calculateValue(NodeExecutionContext context) {
protected abstract class TransformStepBuildOperation implements CallableBuildOperation {
- @UsedByScanPlugin("The string is used for filtering out artifact transform logs in Gradle Enterprise")
+ @UsedByScanPlugin("The string is used for filtering out artifact transform logs in Develocity")
private static final String TRANSFORMING_PROGRESS_PREFIX = "Transforming ";
@Override
diff --git a/settings.gradle.kts b/settings.gradle.kts
index b13023a7e961c..66e1b859d8f21 100644
--- a/settings.gradle.kts
+++ b/settings.gradle.kts
@@ -193,7 +193,7 @@ platform("jvm") {
subproject("war")
}
-// Gradle Enterprise Platform
+// Develocity Platform
platform("enterprise") {
subproject("enterprise")
subproject("enterprise-logging")
diff --git a/subprojects/core/src/main/java/org/gradle/api/internal/TaskOutputsEnterpriseInternal.java b/subprojects/core/src/main/java/org/gradle/api/internal/TaskOutputsEnterpriseInternal.java
index 18274e870b13a..9befa64ce46b5 100644
--- a/subprojects/core/src/main/java/org/gradle/api/internal/TaskOutputsEnterpriseInternal.java
+++ b/subprojects/core/src/main/java/org/gradle/api/internal/TaskOutputsEnterpriseInternal.java
@@ -20,7 +20,7 @@
import org.gradle.api.NonNullApi;
/**
- * Gradle Enterprise specific extensions of {@link TaskOutputsInternal}.
+ * Develocity specific extensions of {@link TaskOutputsInternal}.
*
* This class exists to hide these additional methods from the public API since {@link DefaultTask#getOutputs()}
* returns {@link TaskOutputsInternal} rather than {@link org.gradle.api.tasks.TaskOutputs}.
diff --git a/subprojects/core/src/main/java/org/gradle/api/internal/classpath/DefaultModuleRegistry.java b/subprojects/core/src/main/java/org/gradle/api/internal/classpath/DefaultModuleRegistry.java
index 81c86bf0d12b5..41a280bab0c64 100644
--- a/subprojects/core/src/main/java/org/gradle/api/internal/classpath/DefaultModuleRegistry.java
+++ b/subprojects/core/src/main/java/org/gradle/api/internal/classpath/DefaultModuleRegistry.java
@@ -96,7 +96,7 @@ private DefaultModuleRegistry(ClassLoader classLoader, ClassPath additionalModul
/**
* Determines the name without version when the JAR may have been replaced on the classpath.
*
- * The Test Acceleration plugins from Gradle Enterprise replace some JUnit platform JARS on the test classpath.
+ * The Test Acceleration plugins from Develocity replace some JUnit platform JARS on the test classpath.
* Gradle's testing modules need the original JARs with a possible different version.
* When loading the dependencies from the classpath, this may cause a problem.
* Note that this happens only in integration tests in the Gradle codebase.
diff --git a/subprojects/core/src/main/java/org/gradle/plugin/management/internal/autoapply/AutoAppliedGradleEnterprisePlugin.java b/subprojects/core/src/main/java/org/gradle/plugin/management/internal/autoapply/AutoAppliedGradleEnterprisePlugin.java
index 8279011134c27..216dad9702318 100644
--- a/subprojects/core/src/main/java/org/gradle/plugin/management/internal/autoapply/AutoAppliedGradleEnterprisePlugin.java
+++ b/subprojects/core/src/main/java/org/gradle/plugin/management/internal/autoapply/AutoAppliedGradleEnterprisePlugin.java
@@ -20,7 +20,7 @@
import org.gradle.plugin.use.internal.DefaultPluginId;
/**
- * Auto-applied Gradle Enterprise plugin information.
+ * Auto-applied Develocity plugin information.
*
* Required by the {@code kotlin-dsl} module.
*/
diff --git a/subprojects/core/src/test/groovy/org/gradle/api/internal/classpath/DefaultModuleRegistryTest.groovy b/subprojects/core/src/test/groovy/org/gradle/api/internal/classpath/DefaultModuleRegistryTest.groovy
index 83768305fa952..56513b1c07065 100644
--- a/subprojects/core/src/test/groovy/org/gradle/api/internal/classpath/DefaultModuleRegistryTest.groovy
+++ b/subprojects/core/src/test/groovy/org/gradle/api/internal/classpath/DefaultModuleRegistryTest.groovy
@@ -174,7 +174,7 @@ class DefaultModuleRegistryTest extends Specification {
module.runtimeClasspath.asFiles == [runtimeDep]
}
- def "locates dependency #dependency replaced by Gradle Enterprise plugin to #actualDependencyOnClasspath in classpath"() {
+ def "locates dependency #dependency replaced by Develocity plugin to #actualDependencyOnClasspath in classpath"() {
given:
def dependencyJar = tmpDir.createFile("external/${actualDependencyOnClasspath}.jar")
def moduleDir = createModule("my-testing", properties(runtime: "${dependency}.jar".toString()))
@@ -193,7 +193,7 @@ class DefaultModuleRegistryTest extends Specification {
'opentest4j-1.2.27' | 'opentest4j-1.3.38'
}
- def "does not locate dependency replaced by Gradle Enterprise plugin in classpath when installation is present"() {
+ def "does not locate dependency replaced by Develocity plugin in classpath when installation is present"() {
given:
def dependencyJar = tmpDir.createFile("external/junit-platform-commons-1.9.9.jar")
def moduleDir = createModule("my-testing", properties(runtime: 'junit-platform-commons-1.8.3.jar'))
@@ -206,7 +206,7 @@ class DefaultModuleRegistryTest extends Specification {
e.message.startsWith("Cannot find JAR 'junit-platform-commons-1.8.3.jar' required by module 'gradle-my-testing' using classpath")
}
- def "does not locate dependency not replaced by Gradle Enterprise plugin in classpath"() {
+ def "does not locate dependency not replaced by Develocity plugin in classpath"() {
given:
def dependencyJar = tmpDir.createFile("external/junit-platform-basics-1.9.9.jar")
def moduleDir = createModule("my-testing", properties(runtime: 'junit-platform-basics-1.8.3.jar'))
diff --git a/subprojects/internal-integ-testing/src/main/groovy/org/gradle/internal/scan/config/fixtures/ApplyGradleEnterprisePluginFixture.groovy b/subprojects/internal-integ-testing/src/main/groovy/org/gradle/internal/scan/config/fixtures/ApplyGradleEnterprisePluginFixture.groovy
index b72d892c8bbee..b1fcfbe230f22 100644
--- a/subprojects/internal-integ-testing/src/main/groovy/org/gradle/internal/scan/config/fixtures/ApplyGradleEnterprisePluginFixture.groovy
+++ b/subprojects/internal-integ-testing/src/main/groovy/org/gradle/internal/scan/config/fixtures/ApplyGradleEnterprisePluginFixture.groovy
@@ -21,7 +21,7 @@ import org.gradle.plugin.management.internal.autoapply.AutoAppliedGradleEnterpri
import static org.gradle.plugin.management.internal.autoapply.AutoAppliedGradleEnterprisePlugin.VERSION
/**
- * Applies the Gradle Enterprise plugin via the `settings.gradle` script.
+ * Applies the Develocity plugin via the `settings.gradle` script.
*/
class ApplyGradleEnterprisePluginFixture {
private static final String APPLY_ENTERPRISE_PLUGIN = """plugins {
diff --git a/subprojects/precondition-tester/README.md b/subprojects/precondition-tester/README.md
index b8308717d7ce6..9df346f1bb24f 100644
--- a/subprojects/precondition-tester/README.md
+++ b/subprojects/precondition-tester/README.md
@@ -1,7 +1,7 @@
# Gradle / precondition Tester
This project collections information about where test preconditions can be satisfied.
-We can use this information (i.e. by looking at the test results in Gradle Enterprise) to see if we have any preconditions or combinations of preconditions, which are never satisfied – a situation which we otherwise would hardly notice.
+We can use this information (i.e. by looking at the test results in Develocity) to see if we have any preconditions or combinations of preconditions, which are never satisfied – a situation which we otherwise would hardly notice.
This project originates from a discussion about the [@Requires](https://github.com/gradle/gradle/blob/94ebe9eca6b9baf8c53a6033009298ec671de812/subprojects/internal-testing/src/main/groovy/org/gradle/util/Requires.java), which can define preconditions for tests.
diff --git a/platforms/enterprise/enterprise/src/main/java/org/gradle/internal/enterprise/impl/DefaultGradleEnterprisePluginCheckInService.java b/platforms/enterprise/enterprise/src/main/java/org/gradle/internal/enterprise/impl/DefaultGradleEnterprisePluginCheckInService.java
index 4610d72d71612..951c6b75d264b 100644
--- a/platforms/enterprise/enterprise/src/main/java/org/gradle/internal/enterprise/impl/DefaultGradleEnterprisePluginCheckInService.java
+++ b/platforms/enterprise/enterprise/src/main/java/org/gradle/internal/enterprise/impl/DefaultGradleEnterprisePluginCheckInService.java
@@ -53,17 +53,17 @@ public DefaultGradleEnterprisePluginCheckInService(
public static final String UNSUPPORTED_TOGGLE = "org.gradle.internal.unsupported-enterprise-plugin";
public static final String UNSUPPORTED_TOGGLE_MESSAGE = "Enterprise plugin unsupported due to secret toggle";
// For Gradle versions 8+, configuration caching builds are not compatible with Gradle Enterprise plugin < 3.12
public static final VersionNumber MINIMUM_SUPPORTED_PLUGIN_VERSION_FOR_CONFIGURATION_CACHING = VersionNumber.version(3, 12);
- public static final String UNSUPPORTED_PLUGIN_DUE_TO_CONFIGURATION_CACHING_MESSAGE = String.format("Gradle Enterprise plugin has been disabled as it is " +
- "incompatible with this version of Gradle and the configuration caching feature - please upgrade to version %s.%s or later of the Gradle Enterprise plugin to restore functionality.",
+ public static final String UNSUPPORTED_PLUGIN_DUE_TO_CONFIGURATION_CACHING_MESSAGE = String.format("Develocity plugin has been disabled as it is " +
+ "incompatible with this version of Gradle and the configuration caching feature - please upgrade to version %s.%s or later of the Develocity plugin to restore functionality.",
MINIMUM_SUPPORTED_PLUGIN_VERSION_FOR_CONFIGURATION_CACHING.getMajor(),
MINIMUM_SUPPORTED_PLUGIN_VERSION_FOR_CONFIGURATION_CACHING.getMinor());
public static final VersionNumber MINIMUM_SUPPORTED_PLUGIN_VERSION_FOR_ISOLATED_PROJECTS = VersionNumber.version(3, 15);
- public static final String UNSUPPORTED_PLUGIN_DUE_TO_ISOLATED_PROJECTS_MESSAGE = "Gradle Enterprise plugin has been disabled as it is incompatible with isolated projects feature";
+ public static final String UNSUPPORTED_PLUGIN_DUE_TO_ISOLATED_PROJECTS_MESSAGE = "Develocity plugin has been disabled as it is incompatible with isolated projects feature";
- // Gradle versions 9+ are not compatible Gradle Enterprise plugin < 3.13.1
+ // Gradle versions 9+ are not compatible Develocity plugin < 3.13.1
public static final VersionNumber MINIMUM_SUPPORTED_PLUGIN_VERSION_SINCE_GRADLE_9 = VersionNumber.parse("3.13.1");
private static final String DISABLE_TEST_ACCELERATION_PROPERTY = "gradle.internal.testacceleration.disableImplicitApplication";
@@ -133,8 +133,8 @@ private static boolean isDeprecatedPluginVersion(VersionNumber pluginBaseVersion
}
private static void nagAboutDeprecatedPluginVersion(String pluginVersion) {
- DeprecationLogger.deprecateIndirectUsage("Gradle Enterprise plugin " + pluginVersion)
- .startingWithGradle9(String.format("only Gradle Enterprise plugin %s.%s.%s or newer is supported",
+ DeprecationLogger.deprecateIndirectUsage("Develocity plugin " + pluginVersion)
+ .startingWithGradle9(String.format("only Develocity plugin %s.%s.%s or newer is supported",
MINIMUM_SUPPORTED_PLUGIN_VERSION_SINCE_GRADLE_9.getMajor(),
MINIMUM_SUPPORTED_PLUGIN_VERSION_SINCE_GRADLE_9.getMinor(),
MINIMUM_SUPPORTED_PLUGIN_VERSION_SINCE_GRADLE_9.getMicro()
@@ -53,17 +53,17 @@ public DefaultGradleEnterprisePluginCheckInService(
public static final String UNSUPPORTED_TOGGLE = "org.gradle.internal.unsupported-enterprise-plugin";
public static final String UNSUPPORTED_TOGGLE_MESSAGE = "Enterprise plugin unsupported due to secret toggle";
- // For Gradle versions 8+, configuration caching builds are not compatible with Gradle Enterprise plugin < 3.12
+ // For Gradle versions 8+, configuration caching builds are not compatible with Develocity plugin < 3.12
public static final VersionNumber MINIMUM_SUPPORTED_PLUGIN_VERSION_FOR_CONFIGURATION_CACHING = VersionNumber.version(3, 12);
diff --git a/subprojects/smoke-test/src/smokeTest/groovy/org/gradle/smoketests/BuildScanPluginSmokeTest.groovy b/subprojects/smoke-test/src/smokeTest/groovy/org/gradle/smoketests/BuildScanPluginSmokeTest.groovy
index e00692542112d..ac74d2d0d72f8 100644
--- a/subprojects/smoke-test/src/smokeTest/groovy/org/gradle/smoketests/BuildScanPluginSmokeTest.groovy
+++ b/subprojects/smoke-test/src/smokeTest/groovy/org/gradle/smoketests/BuildScanPluginSmokeTest.groovy
@@ -139,7 +139,7 @@ class BuildScanPluginSmokeTest extends AbstractSmokeTest {
"3.15.1",
]
// Current injection scripts support Gradle Enterprise plugin 3.3 and above
private static final List SUPPORTED_BY_CI_INJECTION = SUPPORTED
.findAll { VersionNumber.parse("3.3") <= VersionNumber.parse(it) }
@@ -171,8 +171,8 @@ class BuildScanPluginSmokeTest extends AbstractSmokeTest {
then:
scanRunner()
.expectLegacyDeprecationWarningIf(FIRST_VERSION_SUPPORTING_CHECK_IN_SERVICE <= versionNumber && versionNumber < FIRST_VERSION_CALLING_BUILD_PATH,
- "Gradle Enterprise plugin $version has been deprecated. " +
- "Starting with Gradle 9.0, only Gradle Enterprise plugin 3.13.1 or newer is supported. " +
+ "Develocity plugin $version has been deprecated. " +
+ "Starting with Gradle 9.0, only Develocity plugin 3.13.1 or newer is supported. " +
"Consult the upgrading guide for further information: https://docs.gradle.org/${GradleVersion.current().version}/userguide/upgrading_version_8.html#unsupported_ge_plugin_3.13"
)
.expectLegacyDeprecationWarningIf(versionNumber < FIRST_VERSION_CALLING_BUILD_PATH,
@@ -198,8 +198,8 @@ class BuildScanPluginSmokeTest extends AbstractSmokeTest {
then:
scanRunner()
.expectLegacyDeprecationWarningIf(versionNumber < FIRST_VERSION_CALLING_BUILD_PATH,
- "Gradle Enterprise plugin $version has been deprecated. " +
- "Starting with Gradle 9.0, only Gradle Enterprise plugin 3.13.1 or newer is supported. " +
+ "Develocity plugin $version has been deprecated. " +
+ "Starting with Gradle 9.0, only Develocity plugin 3.13.1 or newer is supported. " +
"Consult the upgrading guide for further information: https://docs.gradle.org/${GradleVersion.current().version}/userguide/upgrading_version_8.html#unsupported_ge_plugin_3.13"
)
.expectLegacyDeprecationWarningIf(versionNumber < FIRST_VERSION_CALLING_BUILD_PATH,
@@ -224,8 +224,8 @@ class BuildScanPluginSmokeTest extends AbstractSmokeTest {
then:
scanRunner("-Dorg.gradle.unsafe.isolated-projects=true")
.expectLegacyDeprecationWarningIf(versionNumber < FIRST_VERSION_CALLING_BUILD_PATH,
- "Gradle Enterprise plugin $version has been deprecated. " +
- "Starting with Gradle 9.0, only Gradle Enterprise plugin 3.13.1 or newer is supported. " +
+ "Develocity plugin $version has been deprecated. " +
+ "Starting with Gradle 9.0, only Develocity plugin 3.13.1 or newer is supported. " +
"Consult the upgrading guide for further information: https://docs.gradle.org/${GradleVersion.current().version}/userguide/upgrading_version_8.html#unsupported_ge_plugin_3.13"
)
.expectLegacyDeprecationWarningIf(versionNumber < FIRST_VERSION_CALLING_BUILD_PATH,
@@ -251,7 +251,7 @@ class BuildScanPluginSmokeTest extends AbstractSmokeTest {
.build().output
then:
- output.contains("Gradle Enterprise plugin has been disabled as it is incompatible with isolated projects feature")
+ output.contains("Develocity plugin has been disabled as it is incompatible with isolated projects feature")
!output.contains("Build scan written to")
where:
@@ -303,8 +303,8 @@ class BuildScanPluginSmokeTest extends AbstractSmokeTest {
expect:
scanRunner("--init-script", initScript)
.expectLegacyDeprecationWarningIf(FIRST_VERSION_SUPPORTING_CHECK_IN_SERVICE <= versionNumber && versionNumber < FIRST_VERSION_CALLING_BUILD_PATH,
- "Gradle Enterprise plugin $pluginVersion has been deprecated. " +
- "Starting with Gradle 9.0, only Gradle Enterprise plugin 3.13.1 or newer is supported. " +
+ "Develocity plugin $pluginVersion has been deprecated. " +
+ "Starting with Gradle 9.0, only Develocity plugin 3.13.1 or newer is supported. " +
"Consult the upgrading guide for further information: https://docs.gradle.org/${GradleVersion.current().version}/userguide/upgrading_version_8.html#unsupported_ge_plugin_3.13"
)
.expectLegacyDeprecationWarningIf(versionNumber < FIRST_VERSION_CALLING_BUILD_PATH,
@@ -139,7 +139,7 @@ class BuildScanPluginSmokeTest extends AbstractSmokeTest {
"3.15.1",
]
- // Current injection scripts support Gradle Enterprise plugin 3.3 and above
+ // Current injection scripts support Develocity plugin 3.3 and above
private static final List SUPPORTED_BY_CI_INJECTION = SUPPORTED
.findAll { VersionNumber.parse("3.3") <= VersionNumber.parse(it) }